@@ -1,19 +1,19 @@
 package My::Doodad;
 
-# $Id: Doodad.pm,v 2.0 2002/03/19 04:00:06 lachoy Exp $
+# $Id: Doodad.pm,v 2.1 2002/04/26 15:35:22 lachoy Exp $
 
 use strict;
 use SPOPS::Initialize;
 use SPOPS::Secure qw( :level :scope );
 
-$My::Doodad::VERSION = sprintf("%d.%02d", q$Revision: 2.0 $ =~ /(\d+)\.(\d+)/);
+$My::Doodad::VERSION = sprintf("%d.%02d", q$Revision: 2.1 $ =~ /(\d+)\.(\d+)/);
 
 sub _base_config {
    my $config = {
          doodad => {
              class        => 'My::Doodad',
              isa          => [ 'SPOPS::Secure', 'My::Common' ],
-             rules_from   => [ 'My::DiscoverField' ],
+             rules_from   => [ 'SPOPS::Tool::DBI::DiscoverField' ],
              field_discover => 'yes',
              field        => [],
              id_field     => 'doodad_id',
